## What is this package and what does it do?
This package is meant to ease the lives of the analysts and data scientists by providing generalised functions for preprocessing of dataframes and images which are commonly used in Machine Learning.
Additionally, using this package, one can also call various machine learning models as base models with customised data, target, and parameters to check how different models are performing.

## How to use this package?
Simply do:

	pip install ricebowl

and import and use.

"preprocessing.py" contains functions for generalised preprocessing of data in the form of data frames and "images" allow for generalised processing of images as a dataset.

Machine Learning models will be added in the next release.


